(defun fpi/org-babel-get-src-block-hash (&optional block)
  "Return a hash based on src block content and header.

This function tries to not take any file positions into account
and always return the same hash given the same source code and
same header arguments.

`org-babel-sha1-hash' may provide the same feature, but I
discovered that function only after writing this."
  (save-mark-and-excursion
    (if block (org-babel-goto-named-src-block block))
    (let* ((info (or (org-babel-get-src-block-info t)
                     (org-babel-lob-get-info nil t)))
           (body (nth 1 info))
           (header (nth 2 info))
           (hashstring (format "%s%s" body header)))
      (md5 hashstring))))

(setq fpi/org-babel-outfile-directory "/tmp/babel")
(make-directory fpi/org-babel-outfile-directory t)

(defun fpi/org-babel-src-block-temp-file (&optional suffix prefix directory block)
  "Return a unique filename based on src block content and header.

This function is intended as an alternative to
`org-babel-temp-file' to provide unique and constant output
filenames. Optionally provide SUFFIX or PREFIX of the filename
and the file DIRECTORY. If SUFFIX or PREFIX is a list its content
will be concatenated. Default directory is
`org-babel-temporary-directory'. Optionally provide a source
block name BLOCK.
 "
  ;; FIXME Way to create really unique names. In case same code can produce different outputs (e.g. based on time, file context)
  (let ((hash (fpi/org-babel-get-src-block-hash block))
        (directory (or
                    directory
                    fpi/org-babel-outfile-directory))
        (suffix (if (listp suffix)
                    (mapconcat (lambda (x)
                                 (cond ;; FIXME possible to handle all cases without cond?
                                  ((symbolp x) (symbol-name x))
                                  ((numberp x) (number-to-string x))
                                  (t x)
                                  )) suffix "")
                  suffix))
        (prefix (if (listp prefix)
                    (mapconcat (lambda (x)
                                 (cond ;; FIXME possible to handle all cases without cond?
                                  ((symbolp x) (symbol-name x))
                                  ((numberp x) (number-to-string x))
                                  (t x)
                                  )) prefix "")
                  prefix))
        (prefix (or prefix ""))
        )
    (expand-file-name (format "%s%s%s" prefix hash suffix) directory)
    ))
